==> testdisk_6.1.orig.tar.gz: testdisk-6.1.orig/src/intrface.h <==
/*

    File: intrface.h

    Copyright (C) 1998-2004 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */

#define ANALYSE_X	0
#define ANALYSE_Y	5
#define INTER_STRUCTURE	14
#define INTER_BAD_PART	12

int do_curses_testdisk(int debug, int dump_ind, const t_list_disk *list_disk, const int saveheader, const t_arch_fnct **arch, const char *cmd_device, char *cmd_run);
int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, int *menu);

t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
void interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char **current_cmd);
void interface_list(t_param_disk *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup);
int interface_superblock(t_param_disk *disk_car,t_list_part *list_part,char**current_cmd);

==> testdisk_6.4.1.orig.tar.gz: testdisk-6.4.1/src/intrface.h <==
/*

    File: intrface.h

    Copyright (C) 1998-2004 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 59
    Temple Place - Suite 330, Boston MA 02111-1307, USA.

 */

#define ANALYSE_X	0
#define ANALYSE_Y	5
#define INTER_STRUCTURE	13
#define INTER_BAD_PART	10

int do_curses_testdisk(int debug, int dump_ind, const t_list_disk *list_disk, const int saveheader, const char *real_prog_name, const char *cmd_device, char *cmd_run);
int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, int *menu);

t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
void interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char **current_cmd);
void interface_list(t_param_disk *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup);
int interface_superblock(t_param_disk *disk_car,t_list_part *list_part,char**current_cmd);
